@@ -12,7 +12,9 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
+#include "actiongroup.h"
 #include "appinfo.h"
+#include "application.h"
 #include "asyncinitable.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
@@ -93,6 +95,7 @@
 #include "unixfdmessage.h"
 #include "unixinputstream.h"
 #include "unixoutputstream.h"
+#include "unixsocketaddress.h"
 
 extern "C"
 {
@@ -100,6 +103,7 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType g_app_launch_context_get_type(void);
+GType g_application_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
 GType g_cancellable_get_type(void);
@@ -163,6 +167,7 @@ GType g_unix_input_stream_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_output_stream_get_type(void);
 #endif //G_OS_WIN32
+GType g_unix_socket_address_get_type(void);
 GType g_volume_monitor_get_type(void);
 
 //Declarations of the *_error_quark() functions:
@@ -175,6 +180,7 @@ GQuark g_resolver_error_quark(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Cancellable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -238,6 +244,7 @@ namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase*
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+namespace Gio {  class UnixSocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class VolumeMonitor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 
 namespace Gio { 
@@ -250,6 +257,7 @@ void wrap_init()
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
+  Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
   Glib::wrap_register(g_cancellable_get_type(), &Gio::Cancellable_Class::wrap_new);
@@ -313,10 +321,12 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_output_stream_get_type(), &Gio::UnixOutputStream_Class::wrap_new);
 #endif //G_OS_WIN32
+  Glib::wrap_register(g_unix_socket_address_get_type(), &Gio::UnixSocketAddress_Class::wrap_new);
   Glib::wrap_register(g_volume_monitor_get_type(), &Gio::VolumeMonitor_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
+  Gio::Application::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
   Gio::Cancellable::get_type();
@@ -380,6 +390,7 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Gio::UnixOutputStream::get_type();
 #endif //G_OS_WIN32
+  Gio::UnixSocketAddress::get_type();
   Gio::VolumeMonitor::get_type();
 
 } // wrap_init()
